@@ -288,8 +288,10 @@ void PSLib::PS_begin_doc(int, double x, double y, double breite, double hoehe, i
 		PutDoc(BBox);
 		PutDoc(BBoxH);
 	}
-	PutDoc(FNamen);
-	PutDoc(Farben);
+	if (!FNamen.isEmpty())
+		PutDoc("%%DocumentCustomColors: "+FNamen);
+	if (!Farben.isEmpty())
+		PutDoc("%%CMYKCustomColor: "+Farben);
 	PutDoc("%%LanguageLevel: 3\n");
 	PutDoc("%%EndComments\n");
 	PutDoc(Prolog);
@@ -1095,7 +1097,7 @@ int PSLib::CreatePS(ScribusDoc* Doc, std::vector<int> &pageNs, bool sep, QString
 						PageItem *it = Doc->MasterItems.at(api);
 						if ((it->LayerNr != ll.LNr) || (!it->printEnabled()))
 							continue;
-						int x = static_cast<int>(Doc->MasterPages.at(ap)->xOffset());
+/*						int x = static_cast<int>(Doc->MasterPages.at(ap)->xOffset());
 						int y = static_cast<int>(Doc->MasterPages.at(ap)->yOffset());
 						int w = static_cast<int>(Doc->MasterPages.at(ap)->width());
 						int h = static_cast<int>(Doc->MasterPages.at(ap)->height());
@@ -1105,6 +1107,17 @@ int PSLib::CreatePS(ScribusDoc* Doc, std::vector<int> &pageNs, bool sep, QString
 						int w2 = static_cast<int>(it->BoundingW + ilw);
 						int h2 = static_cast<int>(it->BoundingH + ilw);
 						if (!QRect(x, y, w, h).intersects(QRect(x2, y2, w2, h2)))
+							continue; */
+						double x = Doc->MasterPages.at(ap)->xOffset();
+						double y = Doc->MasterPages.at(ap)->yOffset();
+						double w = Doc->MasterPages.at(ap)->width();
+						double h1 = Doc->MasterPages.at(ap)->height();
+						double ilw = it->lineWidth();
+						double x2 = it->BoundingX - ilw / 2.0;
+						double y2 = it->BoundingY - ilw / 2.0;
+						double w2 = it->BoundingW + ilw;
+						double h2 = it->BoundingH + ilw;
+						if (!( QMAX( x, x2 ) <= QMIN( x+w, x2+w2 ) && QMAX( y, y2 ) <= QMIN( y+h1, y2+h2 )))
 							continue;
 						if ((it->OwnPage != static_cast<int>(Doc->MasterPages.at(ap)->pageNr())) && (it->OwnPage != -1))
 							continue;
@@ -1313,14 +1326,17 @@ int PSLib::CreatePS(ScribusDoc* Doc, std::vector<int> &pageNs, bool sep, QString
 										multiLine ml = Doc->MLineStyles[ite->NamedLStyle];
 										for (int it = ml.size()-1; it > -1; it--)
 										{
-											SetFarbe(ml[it].Color, ml[it].Shade, &h, &s, &v, &k, gcr);
-											PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
-											PS_setlinewidth(ml[it].Width);
-											PS_setcapjoin(static_cast<Qt::PenCapStyle>(ml[it].LineEnd), static_cast<Qt::PenJoinStyle>(ml[it].LineJoin));
-											PS_setdash(static_cast<Qt::PenStyle>(ml[it].Dash), 0, dum);
-											SetClipPath(&ite->PoLine);
-											PS_closepath();
-											putColor(ml[it].Color, ml[it].Shade, false);
+											if ((ml[it].Color != CommonStrings::None) && (ml[it].Width != 0))
+											{
+												SetFarbe(ml[it].Color, ml[it].Shade, &h, &s, &v, &k, gcr);
+												PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
+												PS_setlinewidth(ml[it].Width);
+												PS_setcapjoin(static_cast<Qt::PenCapStyle>(ml[it].LineEnd), static_cast<Qt::PenJoinStyle>(ml[it].LineJoin));
+												PS_setdash(static_cast<Qt::PenStyle>(ml[it].Dash), 0, dum);
+												SetClipPath(&ite->PoLine);
+												PS_closepath();
+												putColor(ml[it].Color, ml[it].Shade, false);
+											}
 										}
 									}
 								}
@@ -1333,6 +1349,8 @@ int PSLib::CreatePS(ScribusDoc* Doc, std::vector<int> &pageNs, bool sep, QString
 						PageItem *ite = Doc->Pages->at(a)->FromMaster.at(am);
 						if (!ite->isTableItem)
 							continue;
+						if ((ite->lineColor() == CommonStrings::None) || (ite->lineWidth() == 0.0))
+							continue;
 						if (ite->printEnabled())
 						{
 							PS_save();
@@ -1501,14 +1519,17 @@ void PSLib::ProcessItem(ScribusDoc* Doc, Page* a, PageItem* c, uint PNr, bool se
 					multiLine ml = Doc->MLineStyles[c->NamedLStyle];
 					for (int it = ml.size()-1; it > -1; it--)
 					{
-						SetFarbe(ml[it].Color, ml[it].Shade, &h, &s, &v, &k, gcr);
-						PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
-						PS_setlinewidth(ml[it].Width);
-						PS_setcapjoin(static_cast<Qt::PenCapStyle>(ml[it].LineEnd), static_cast<Qt::PenJoinStyle>(ml[it].LineJoin));
-						PS_setdash(static_cast<Qt::PenStyle>(ml[it].Dash), 0, dum);
-						SetClipPath(&c->PoLine);
-						PS_closepath();
-						putColor(ml[it].Color, ml[it].Shade, false);
+						if ((ml[it].Color != CommonStrings::None) && (ml[it].Width != 0))
+						{
+							SetFarbe(ml[it].Color, ml[it].Shade, &h, &s, &v, &k, gcr);
+							PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
+							PS_setlinewidth(ml[it].Width);
+							PS_setcapjoin(static_cast<Qt::PenCapStyle>(ml[it].LineEnd), static_cast<Qt::PenJoinStyle>(ml[it].LineJoin));
+							PS_setdash(static_cast<Qt::PenStyle>(ml[it].Dash), 0, dum);
+							SetClipPath(&c->PoLine);
+							PS_closepath();
+							putColor(ml[it].Color, ml[it].Shade, false);
+						}
 					}
 				}
 			}
@@ -1577,14 +1598,17 @@ void PSLib::ProcessItem(ScribusDoc* Doc, Page* a, PageItem* c, uint PNr, bool se
 					multiLine ml = Doc->MLineStyles[c->NamedLStyle];
 					for (int it = ml.size()-1; it > -1; it--)
 					{
-						SetFarbe(ml[it].Color, ml[it].Shade, &h, &s, &v, &k, gcr);
-						PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
-						PS_setlinewidth(ml[it].Width);
-						PS_setcapjoin(static_cast<Qt::PenCapStyle>(ml[it].LineEnd), static_cast<Qt::PenJoinStyle>(ml[it].LineJoin));
-						PS_setdash(static_cast<Qt::PenStyle>(ml[it].Dash), 0, dum);
-						SetClipPath(&c->PoLine);
-						PS_closepath();
-						putColor(ml[it].Color, ml[it].Shade, false);
+						if ((ml[it].Color != CommonStrings::None) && (ml[it].Width != 0))
+						{
+							SetFarbe(ml[it].Color, ml[it].Shade, &h, &s, &v, &k, gcr);
+							PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
+							PS_setlinewidth(ml[it].Width);
+							PS_setcapjoin(static_cast<Qt::PenCapStyle>(ml[it].LineEnd), static_cast<Qt::PenJoinStyle>(ml[it].LineJoin));
+							PS_setdash(static_cast<Qt::PenStyle>(ml[it].Dash), 0, dum);
+							SetClipPath(&c->PoLine);
+							PS_closepath();
+							putColor(ml[it].Color, ml[it].Shade, false);
+						}
 					}
 				}
 			}
@@ -1601,14 +1625,17 @@ void PSLib::ProcessItem(ScribusDoc* Doc, Page* a, PageItem* c, uint PNr, bool se
 				multiLine ml = Doc->MLineStyles[c->NamedLStyle];
 				for (int it = ml.size()-1; it > -1; it--)
 				{
-					SetFarbe(ml[it].Color, ml[it].Shade, &h, &s, &v, &k, gcr);
-					PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
-					PS_setlinewidth(ml[it].Width);
-					PS_setcapjoin(static_cast<Qt::PenCapStyle>(ml[it].LineEnd), static_cast<Qt::PenJoinStyle>(ml[it].LineJoin));
-					PS_setdash(static_cast<Qt::PenStyle>(ml[it].Dash), 0, dum);
-					PS_moveto(0, 0);
-					PS_lineto(c->width(), 0);
-					putColor(ml[it].Color, ml[it].Shade, false);
+					if ((ml[it].Color != CommonStrings::None) && (ml[it].Width != 0))
+					{
+						SetFarbe(ml[it].Color, ml[it].Shade, &h, &s, &v, &k, gcr);
+						PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
+						PS_setlinewidth(ml[it].Width);
+						PS_setcapjoin(static_cast<Qt::PenCapStyle>(ml[it].LineEnd), static_cast<Qt::PenJoinStyle>(ml[it].LineJoin));
+						PS_setdash(static_cast<Qt::PenStyle>(ml[it].Dash), 0, dum);
+						PS_moveto(0, 0);
+						PS_lineto(c->width(), 0);
+						putColor(ml[it].Color, ml[it].Shade, false);
+					}
 				}
 			}
 			if (c->startArrowIndex() != 0)
@@ -1671,14 +1698,17 @@ void PSLib::ProcessItem(ScribusDoc* Doc, Page* a, PageItem* c, uint PNr, bool se
 					multiLine ml = Doc->MLineStyles[c->NamedLStyle];
 					for (int it = ml.size()-1; it > -1; it--)
 					{
-						SetFarbe(ml[it].Color, ml[it].Shade, &h, &s, &v, &k, gcr);
-						PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
-						PS_setlinewidth(ml[it].Width);
-						PS_setcapjoin(static_cast<Qt::PenCapStyle>(ml[it].LineEnd), static_cast<Qt::PenJoinStyle>(ml[it].LineJoin));
-						PS_setdash(static_cast<Qt::PenStyle>(ml[it].Dash), 0, dum);
-						SetClipPath(&c->PoLine);
-						PS_closepath();
-						putColor(ml[it].Color, ml[it].Shade, false);
+						if ((ml[it].Color != CommonStrings::None) && (ml[it].Width != 0))
+						{
+							SetFarbe(ml[it].Color, ml[it].Shade, &h, &s, &v, &k, gcr);
+							PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
+							PS_setlinewidth(ml[it].Width);
+							PS_setcapjoin(static_cast<Qt::PenCapStyle>(ml[it].LineEnd), static_cast<Qt::PenJoinStyle>(ml[it].LineJoin));
+							PS_setdash(static_cast<Qt::PenStyle>(ml[it].Dash), 0, dum);
+							SetClipPath(&c->PoLine);
+							PS_closepath();
+							putColor(ml[it].Color, ml[it].Shade, false);
+						}
 					}
 				}
 			}
@@ -1706,13 +1736,16 @@ void PSLib::ProcessItem(ScribusDoc* Doc, Page* a, PageItem* c, uint PNr, bool se
 					multiLine ml = Doc->MLineStyles[c->NamedLStyle];
 					for (int it = ml.size()-1; it > -1; it--)
 					{
-						SetFarbe(ml[it].Color, ml[it].Shade, &h, &s, &v, &k, gcr);
-						PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
-						PS_setlinewidth(ml[it].Width);
-						PS_setcapjoin(static_cast<Qt::PenCapStyle>(ml[it].LineEnd), static_cast<Qt::PenJoinStyle>(ml[it].LineJoin));
-						PS_setdash(static_cast<Qt::PenStyle>(ml[it].Dash), 0, dum);
-						SetClipPath(&c->PoLine, false);
-						putColor(ml[it].Color, ml[it].Shade, false);
+						if ((ml[it].Color != CommonStrings::None) && (ml[it].Width != 0))
+						{
+							SetFarbe(ml[it].Color, ml[it].Shade, &h, &s, &v, &k, gcr);
+							PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
+							PS_setlinewidth(ml[it].Width);
+							PS_setcapjoin(static_cast<Qt::PenCapStyle>(ml[it].LineEnd), static_cast<Qt::PenJoinStyle>(ml[it].LineJoin));
+							PS_setdash(static_cast<Qt::PenStyle>(ml[it].Dash), 0, dum);
+							SetClipPath(&c->PoLine, false);
+							putColor(ml[it].Color, ml[it].Shade, false);
+						}
 					}
 				}
 			}
@@ -1783,13 +1816,16 @@ void PSLib::ProcessItem(ScribusDoc* Doc, Page* a, PageItem* c, uint PNr, bool se
 						multiLine ml = Doc->MLineStyles[c->NamedLStyle];
 						for (int it = ml.size()-1; it > -1; it--)
 						{
-							SetFarbe(ml[it].Color, ml[it].Shade, &h, &s, &v, &k, gcr);
-							PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
-							PS_setlinewidth(ml[it].Width);
-							PS_setcapjoin(static_cast<Qt::PenCapStyle>(ml[it].LineEnd), static_cast<Qt::PenJoinStyle>(ml[it].LineJoin));
-							PS_setdash(static_cast<Qt::PenStyle>(ml[it].Dash), 0, dum);
-							SetClipPath(&c->PoLine, false);
-							putColor(ml[it].Color, ml[it].Shade, false);
+							if ((ml[it].Color != CommonStrings::None) && (ml[it].Width != 0))
+							{
+								SetFarbe(ml[it].Color, ml[it].Shade, &h, &s, &v, &k, gcr);
+								PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
+								PS_setlinewidth(ml[it].Width);
+								PS_setcapjoin(static_cast<Qt::PenCapStyle>(ml[it].LineEnd), static_cast<Qt::PenJoinStyle>(ml[it].LineJoin));
+								PS_setdash(static_cast<Qt::PenStyle>(ml[it].Dash), 0, dum);
+								SetClipPath(&c->PoLine, false);
+								putColor(ml[it].Color, ml[it].Shade, false);
+							}
 						}
 					}
 					PS_restore();
@@ -1848,6 +1884,19 @@ void PSLib::ProcessItem(ScribusDoc* Doc, Page* a, PageItem* c, uint PNr, bool se
 								PS_translate(0, -c->BaseOffs);
 							if (hl->cscale != 1000)
 								PS_scale(hl->cscale / 1000.0, 1);
+							if ((hl->cstyle & 256) && ((hl->cstroke != CommonStrings::None)))
+							{
+								PS_save();
+								PS_translate(tsz * hl->cshadowx / 10000.0, tsz * -hl->cshadowy / 10000.0);
+								SetFarbe(hl->cstroke, hl->cshade2, &h, &s, &v, &k, gcr);
+								PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
+								if ((colorsToUse[hl->cstroke].isSpotColor()) && (!DoSep))
+									PutSeite(ToStr(hl->cshade2 / 100.0)+" "+spotMap[hl->cstroke]);
+								else
+									PutSeite(StrokeColor + " cmyk");
+								PS_showSub(chr, hl->cfont->RealName().simplifyWhiteSpace().replace( QRegExp("[\\s\\/\\{\\[\\]\\}\\<\\>\\(\\)\\%]"), "_" ), tsz / 10.0, false);
+								PS_restore();
+							}
 							if ((colorsToUse[hl->ccolor].isSpotColor()) && (!DoSep))
 								PutSeite(ToStr(hl->cshade / 100.0)+" "+spotMap[hl->ccolor]);
 							else
@@ -1879,6 +1928,26 @@ void PSLib::ProcessItem(ScribusDoc* Doc, Page* a, PageItem* c, uint PNr, bool se
 					PutSeite("["+ToStr(0) + " " + ToStr(0) + " " + ToStr(0) + " " + ToStr(0) + " " + ToStr(0) + " " + ToStr(0) + "] concatmatrix\nconcat\n");
 					if (c->BaseOffs != 0)
 						PS_translate(0, -c->BaseOffs);
+					if ((hl->cstyle & 256) && ((hl->cstroke != CommonStrings::None)))
+					{
+						PS_save();
+						PS_translate(tsz * hl->cshadowx / 10000.0, tsz * -hl->cshadowy / 10000.0);
+						SetFarbe(hl->cstroke, hl->cshade2, &h, &s, &v, &k, gcr);
+						PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
+						if ((colorsToUse[hl->cstroke].isSpotColor()) && (!DoSep))
+						{
+							PutSeite(ToStr(hl->cshade2 / 100.0)+" "+spotMap[hl->cstroke]);
+							PS_show_xyG(hl->cfont->scName(), chx, 0, 0, true);
+						}
+						else
+							PS_show_xyG(hl->cfont->scName(), chx, 0, 0, false);
+						PS_restore();
+					}
+					if (hl->ccolor != CommonStrings::None)
+					{
+						SetFarbe(hl->ccolor, hl->cshade, &h, &s, &v, &k, gcr);
+						PS_setcmykcolor_stroke(h / 255.0, s / 255.0, v / 255.0, k / 255.0);
+					}
 					if ((colorsToUse[hl->ccolor].isSpotColor()) && (!DoSep))
 					{
 						PutSeite(ToStr(hl->cshade / 100.0)+" "+spotMap[hl->ccolor]);
@@ -1987,6 +2056,8 @@ void PSLib::ProcessPage(ScribusDoc* Doc, Page* a, uint PNr, bool sep, bool farb,
 				continue;
 			if (!c->isTableItem)
 				continue;
+			if ((c->lineColor() == CommonStrings::None) || (c->lineWidth() == 0.0))
+				continue;
 			if ((!a->PageNam.isEmpty()) && (c->OwnPage != static_cast<int>(a->pageNr())) && (c->OwnPage != -1))
 				continue;
 			if (c->printEnabled())
@@ -2042,7 +2113,7 @@ void PSLib::HandleGradient(PageItem *c, double w, double h, bool gcr)
 	double EndX = 0;
 	double EndY =0;
 	QPtrVector<VColorStop> cstops = c->fill_gradient.colorStops();
-	switch (c->GrType)
+/*	switch (c->GrType)
 	{
 		case 1:
 			StartX = 0;
@@ -2089,7 +2160,11 @@ void PSLib::HandleGradient(PageItem *c, double w, double h, bool gcr)
 			EndX = c->GrEndX;
 			EndY = c->GrEndY;
 			break;
-	}
+	} */
+	StartX = c->GrStartX;
+	StartY = c->GrStartY;
+	EndX = c->GrEndX;
+	EndY = c->GrEndY;
 	QValueList<double> StopVec;
 	QStringList Gcolors;
 	QString hs,ss,vs,ks;
@@ -2241,6 +2316,9 @@ void PSLib::setTextSt(ScribusDoc* Doc, PageItem* ite, bool gcr, uint a, Page* pg
 			hl2.cshade2 = hl->cshade2;
 			hl2.yp = hl->yp - (hl->csize * hl->cshadowy / 10000.0);
 			hl2.xp = hl->xp + (hl->csize * hl->cshadowx / 10000.0);
+			hl2.PtransX = hl->PtransX;
+			hl2.PtransY = hl->PtransY;
+			hl2.PRot = hl->PRot;
 			hl2.csize = hl->csize;
 			hl2.cstyle = hl->cstyle;
 			hl2.cfont = hl->cfont;
